<?php
/**
 * Broad wordpress version check
 *
 * Prevents Broad from running on WordPress versions prior to 3.5,
 * since this theme is not meant to be backward compatible beyond that and
 * relies on many newer functions and markup changes introduced in 3.5.
 *
 * @package Broad
 * @since Broad 1.0
 */

/**
 * Prevent switching to Broad on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since Broad 1.0
 */
function broad_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'broad_upgrade_notice' );
}
add_action( 'after_switch_theme', 'broad_switch_theme' );

/**
 * Add message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * Broad on WordPress versions prior to 3.5.
 *
 * @since Broad 1.0
 * 
 * @global string $wp_version WordPress version. 
 */
function broad_upgrade_notice() {
	$message = sprintf( __( 'Broad requires at least WordPress version 3.5. You are running version %s. Please upgrade and try again.', 'broad' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 3.5.
 *
 * @since Broad 1.0
 *
 * @global string $wp_version WordPress version.
 */
function broad_customize() {
	wp_die( sprintf( __( 'Broad requires at least WordPress version 3.5. You are running version %s. Please upgrade and try again.', 'broad' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'broad_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 3.5.
 *
 * @since Broad 1.0
 *
 * @global string $wp_version WordPress version.
 */
function broad_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'Broad requires at least WordPress version 3.5. You are running version %s. Please upgrade and try again.', 'broad' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'broad_preview' );

?>