<?php
/**
 * Broad Customizer functionality
 *
 * @package Broad
 * @since Broad 1.0
 */

/**
 * Add postMessage support for site title and description for the Customizer.
 *
 * @since Broad 1.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function broad_customize_register( $wp_customize ) {

	// Add custom header background color setting and control.
	$wp_customize->add_setting( 'header_bg_color', array(
		'default'           => '#d3670e',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_bg_color', array(
		'label'       => __( 'Header Background Color', 'broad' ),
		'description' => __( 'Applied to the header.', 'broad' ),
		'section'     => 'colors',
	) ) );
	
	// Add custom navigation background color setting and control.
	$wp_customize->add_setting( 'nav_bg_color', array(
		'default'           => '#222222',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'nav_bg_color', array(
		'label'       => __( 'Navigation Background Color', 'broad' ),
		'description' => __( 'Applied to the navigation.', 'broad' ),
		'section'     => 'colors',
	) ) );
	
	// Add custom navigation link color setting and control.
	$wp_customize->add_setting( 'nav_li_color', array(
		'default'           => '#d3670e',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'nav_li_color', array(
		'label'       => __( 'Navigation Link Color', 'broad' ),
		'description' => __( 'Applied to the navigation link.', 'broad' ),
		'section'     => 'colors',
	) ) );

	// Add custom top menu color setting and control.
	$wp_customize->add_setting( 'top_menu_bg_color', array(
		'default'           => '#d3670e',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_menu_bg_color', array(
		'label'       => __( 'Top Menu Background Color', 'broad' ),
		'description' => __( 'Applied to all top menu.', 'broad' ),
		'section'     => 'colors',
	) ) );

	
	// Add custom content background color setting and control.
	$wp_customize->add_setting( 'content_bgcolor', array(
		'default'           => '#e7e7e7',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'content_bgcolor', array(
		'label'       => __( 'Content Background Color', 'broad' ),
		'description' => __( 'Applied to all content background color.', 'broad' ),
		'section'     => 'colors',
	) ) );

	// Add custom content color setting and control.
	$wp_customize->add_setting( 'content_color', array(
		'default'           => '#000000',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'content_color', array(
		'label'       => __( 'Content Color', 'broad' ),
		'description' => __( 'Applied to all content color.', 'broad' ),
		'section'     => 'colors',
	) ) );
	
	// Add custom content mouseover background color setting and control.
	$wp_customize->add_setting( 'content_mouseover_bgcolor', array(
		'default'           => '#d3670e',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'content_mouseover_bgcolor', array(
		'label'       => __( 'Content Mouseover Background Color', 'broad' ),
		'description' => __( 'Applied to all content mouseover background color.', 'broad' ),
		'section'     => 'colors',
	) ) );

	// Add custom content mouseover color setting and control.
	$wp_customize->add_setting( 'content_mouseover_color', array(
		'default'           => '#FFFFFF',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'content_mouseover_color', array(
		'label'       => __( 'Content Mouseover Color', 'broad' ),
		'description' => __( 'Applied to all content mouseover.', 'broad' ),
		'section'     => 'colors',
	) ) );
	

	// Add custom footer background color setting and control.
	$wp_customize->add_setting( 'footer_bg_color', array(
		'default'           => '#d3670e',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_bg_color', array(
		'label'       => __( 'Footer Background Color', 'broad' ),
		'description' => __( 'Applied to the footer.', 'broad' ),
		'section'     => 'colors',
	) ) );
	
	// Add custom footer text color setting and control.
	$wp_customize->add_setting( 'footer_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_color', array(
		'label'       => __( 'Footer Text Color', 'broad' ),
		'description' => __( 'Applied to the footer.', 'broad' ),
		'section'     => 'colors',
	) ) );

	// Add custom footer link color setting and control.
	$wp_customize->add_setting( 'footer_link_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_link_color', array(
		'label'       => __( 'Footer Link Color', 'broad' ),
		'description' => __( 'Applied to the footer direct links.', 'broad' ),
		'section'     => 'colors',
	) ) );

	// Add custom link color setting and control.
	$wp_customize->add_setting( 'link_color', array(
		'default'           => '#d3670e',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
		'label'       => __( 'Link Color', 'broad' ),
		'description' => __( 'Applied to all direct link.', 'broad' ),
		'section'     => 'colors',
	) ) );
	
	// Add custom button background color setting and control.
	$wp_customize->add_setting( 'button_bg_color', array(
		'default'           => '#d3670e',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'refresh',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_bg_color', array(
		'label'       => __( 'Button Background Color', 'broad' ),
		'description' => __( 'Applied to all button.', 'broad' ),
		'section'     => 'colors',
	) ) );
                                              
}
add_action( 'customize_register', 'broad_customize_register', 11 );


/**
 * Output the css.
 *
 * @since Broad 1.0                                          
 */
function broad_customize_css() {
	$footer_background_image = broad_get_option_data('footer_background_image');
	if ($footer_background_image->option_activate == 1) {
		$footer_background_image = 'url("' . $footer_background_image->option_value . '") repeat scroll center top ';
	} else {
		$footer_background_image = '';
	}	
	?>
	<style type="text/css">
		header.header { background: <?php echo get_theme_mod('header_bg_color'); ?>; }
		a, a:hover, a:focus { color: <?php echo get_theme_mod('link_color'); ?>; }
		.navbar-inverse {
			background: <?php echo get_theme_mod('nav_bg_color'); ?>;
			border-color: <?php echo get_theme_mod('nav_bg_color'); ?>;
		}
		.navbar-inverse .navbar-nav > li > a {
			color: <?php echo get_theme_mod('nav_li_color'); ?>;
		}
		.navbar-inverse .navbar-nav > li > a:focus,
		.navbar-inverse .navbar-nav > li > a:hover,
		.navbar-inverse .navbar-nav > li > a:active,
		.navbar-inverse .navbar-toggle:focus,
		.navbar-inverse .navbar-toggle:hover,
		.navbar-inverse .navbar-brand:focus,
		.navbar-inverse .navbar-brand:hover,
		a.active-home,
		li.active a,
		.dropdown-menu > li > a:focus,
		.dropdown-menu > li > a:hover { background: <?php echo get_theme_mod('header_bg_color'); ?> !important; }
		
    	section.col-sm-8 div.top-menu, div.top-menu { background: <?php echo get_theme_mod('top_menu_bg_color'); ?> !important; }
    	
    	.btn-primary, .btn-primary:hover {
    		background: <?php echo get_theme_mod('button_bg_color'); ?>;
    		border-color: <?php echo get_theme_mod('button_bg_color'); ?>;
    	}
    	.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button { background-color: <?php echo get_theme_mod('button_bg_color'); ?>; }
    	article.comment-body > .reply > a.comment-reply-link { background: <?php echo get_theme_mod('button_bg_color'); ?>; }
    	
    	.control-slide { color: <?php echo get_theme_mod('button_bg_color'); ?>; }
    	    	
    	main.main > .row > .col-lg-12 > section > nav > ul.pager li > a:focus, .pager li > a:hover { background-color: <?php echo get_theme_mod('button_bg_color'); ?>; }
    	main.main > .row > .col-lg-12 > section > div#content > article > a.article-readmore { background: <?php echo get_theme_mod('button_bg_color'); ?>; }
    	
    	article.comment-body > .comment-content { border-bottom: 2px dotted <?php echo get_theme_mod('top_menu_bg_color'); ?>; }
    	#commentform .form-control:focus, #commentform .form-control:hover { border-color: <?php echo get_theme_mod('top_menu_bg_color'); ?>; }
    	.tooltip-inner { background: <?php echo get_theme_mod('top_menu_bg_color'); ?>; }
    	.tooltip.top .tooltip-arrow { border-top-color: <?php echo get_theme_mod('top_menu_bg_color'); ?>; }
    	
		main.main > .row > .col-lg-12 > section > div#content > article, main.main > .row > .col-lg-12 > aside > article, main.main > .row > .col-lg-12 > aside > div.widget > article {
		    background: none repeat scroll 0% 0% <?php echo get_theme_mod('content_bgcolor'); ?>;
		    color: <?php echo get_theme_mod('content_color'); ?>;                     
		}
		
		main.main > .row > .col-lg-12 > section > div#content > article.hover:hover {
		    background: <?php echo get_theme_mod('content_mouseover_bgcolor'); ?>;
		    color: <?php echo get_theme_mod('content_mouseover_color'); ?>;
		    box-shadow: 1px 1px 18px <?php echo get_theme_mod('content_mouseover_bgcolor'); ?>;
		}
		
		main.main > .row > .col-lg-12 > aside > article > ul > li::before { color: <?php echo get_theme_mod('link_color'); ?>; }
		footer.footer { background: <?php echo $footer_background_image; ?> <?php echo get_theme_mod('footer_bg_color'); ?> !important; color: <?php echo get_theme_mod('footer_color'); ?> !important;	}
		footer.footer a[href] { color: <?php echo get_theme_mod('footer_link_color'); ?>; }
		footer.footer caption { color: <?php echo get_theme_mod('footer_color'); ?>; }
		
	</style>
	<?php
}
add_action( 'wp_head', 'broad_customize_css' );


/**
 * Register color schemes for Broad.
 *
 * Can be filtered with {@see 'broad_color_schemes'}.
 *
 * The order of colors in a colors array:
 * 1. Main Background Color.
 * 2. Sidebar Background Color.
 * 3. Box Background Color.
 * 4. Main Text and Link Color.
 * 5. Sidebar Text and Link Color.
 * 6. Meta Box Background Color.
 *
 * @since Broad 1.0
 *
 * @return array An associative array of color scheme options.
 */
function broad_get_color_schemes() {
	/**
	 * Filter the color schemes registered for use with Broad.
	 *
	 * The default schemes include 'default', 'dark', 'yellow', 'pink', 'purple', and 'blue'.
	 *
	 * @since Broad 1.0
	 *
	 * @param array $schemes {
	 *     Associative array of color schemes data.
	 *
	 *     @type array $slug {
	 *         Associative array of information for setting up the color scheme.
	 *
	 *         @type string $label  Color scheme label.
	 *         @type array  $colors HEX codes for default colors prepended with a hash symbol ('#').
	 *                              Colors are defined in the following order: Main background, sidebar
	 *                              background, box background, main text and link, sidebar text and link,
	 *                              meta box background.
	 *     }
	 * }
	 */
	return apply_filters( 'broad_color_schemes', array(
		'default' => array(
			'label'  => __( 'Default', 'broad' ),
			'colors' => array(
				'#f1f1f1',
				'#ffffff',
				'#ffffff',
				'#333333',
				'#333333',
				'#f7f7f7',
			),
		),
		'dark'    => array(
			'label'  => __( 'Dark', 'broad' ),
			'colors' => array(
				'#111111',
				'#202020',
				'#202020',
				'#bebebe',
				'#bebebe',
				'#1b1b1b',
			),
		),
		'yellow'  => array(
			'label'  => __( 'Yellow', 'broad' ),
			'colors' => array(
				'#f4ca16',
				'#ffdf00',
				'#ffffff',
				'#111111',
				'#111111',
				'#f1f1f1',
			),
		),
		'pink'    => array(
			'label'  => __( 'Pink', 'broad' ),
			'colors' => array(
				'#ffe5d1',
				'#e53b51',
				'#ffffff',
				'#352712',
				'#ffffff',
				'#f1f1f1',
			),
		),
		'purple'  => array(
			'label'  => __( 'Purple', 'broad' ),
			'colors' => array(
				'#674970',
				'#2e2256',
				'#ffffff',
				'#2e2256',
				'#ffffff',
				'#f1f1f1',
			),
		),
		'blue'   => array(
			'label'  => __( 'Blue', 'broad' ),
			'colors' => array(
				'#e9f2f9',
				'#55c3dc',
				'#ffffff',
				'#22313f',
				'#ffffff',
				'#f1f1f1',
			),
		),
	) );
}

if ( ! function_exists( 'broad_get_color_scheme' ) ) :
/**
 * Get the current Broad color scheme.
 *
 * @since Broad 1.0
 *
 * @return array An associative array of either the current or default color scheme hex values.
 */
function broad_get_color_scheme() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );
	$color_schemes       = broad_get_color_schemes();

	if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {
		return $color_schemes[ $color_scheme_option ]['colors'];
	}

	return $color_schemes['default']['colors'];
}
endif; // broad_get_color_scheme

if ( ! function_exists( 'broad_get_color_scheme_choices' ) ) :
/**
 * Returns an array of color scheme choices registered for Broad.
 *
 * @since Broad 1.0
 *
 * @return array Array of color schemes.
 */
function broad_get_color_scheme_choices() {
	$color_schemes                = broad_get_color_schemes();
	$color_scheme_control_options = array();

	foreach ( $color_schemes as $color_scheme => $value ) {
		$color_scheme_control_options[ $color_scheme ] = $value['label'];
	}

	return $color_scheme_control_options;
}
endif; // broad_get_color_scheme_choices

if ( ! function_exists( 'broad_sanitize_color_scheme' ) ) :
/**
 * Sanitization callback for color schemes.
 *
 * @since Broad 1.0
 *
 * @param string $value Color scheme name value.
 * @return string Color scheme name.
 */
function broad_sanitize_color_scheme( $value ) {
	$color_schemes = broad_get_color_scheme_choices();

	if ( ! array_key_exists( $value, $color_schemes ) ) {
		$value = 'default';
	}

	return $value;
}
endif; // broad_sanitize_color_scheme