<?php
/**
 * Custom template tags for Broad
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Broad 
 * @since Broad 1.0
 */

if ( ! function_exists( 'broad_comment_nav' ) ) :
/**
 * Display navigation to next/previous comments when applicable.
 *
 * @since Broad 1.0
 */
function broad_comment_nav() {
	// Are there comments to navigate through?
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
	?>                                                           
	<nav class="navigation comment-navigation" role="navigation">
		<h2 class="screen-reader-text"><?php _e( 'Comment navigation', 'broad' ); ?></h2>
		<ul class="pager">
			<?php
				if ( $next_link = get_next_comments_link( __( '<span id="left"></span>Newer comments', 'broad' ) ) ) : printf( '<li class="previous">%s</li>', $next_link ); endif;
				if ( $prev_link = get_previous_comments_link( __( 'Older comments <span id="right"></span>', 'broad' ) ) ) : printf( '<li class="next">%s</li>', $prev_link ); endif;
			?>
		</ul><!-- .pager -->          
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}
endif;

if ( ! function_exists( 'broad_entry_meta' ) ) :
/**
 * Prints HTML with meta information for the categories, tags.
 *
 * @since Broad 1.0
 */
function broad_entry_meta() {                                                               
    
	$format = get_post_format();
	if ( current_theme_supports( 'post-formats', $format ) ) {
		$post_layout = broad_get_option_data('post_layout');
		$class = ($post_layout->option_activate == 'masonry' && !is_single()) ? 'col-lg-12' : 'col-lg-2'; 
		$style = ($post_layout->option_activate == 'masonry' && !is_single()) ? 'style="padding: 3%;"' : '';
		 
		printf( '%1$s<a href="%2$s" class="%4$s article-format" %5$s>%3$s</a>',
			sprintf( '<span class="screen-reader-text">%s </span>',_x( 'Format', 'Used before post format.', 'broad' ) ),
			esc_url( get_post_format_link( $format ) ),
			get_post_format_string( $format ),
			$class,
			$style
		);
	}
	
	?>
    <details class="col-lg-12 article-details">
	<?php
	if ( is_page() ) {
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			comments_popup_link(
				 __( 'Leave a comment', 'broad' ),
				 __( '1 Comment', 'broad' ),
				 __( '% Comments', 'broad' ), 'col-lg-4 pull-left',
				 __( 'Commenting is off', 'broad' )
			);
		}
		if ( ! post_password_required() && ( !comments_open() ) ) { $edit_class = 'col-lg-12'; } else { $edit_class = 'col-lg-4 pull-right'; } 
		if ( current_user_can('edit_posts') ) {
			printf( '%1$s<a href="%2$s" class="%4$s"><span id="edit-icon"></span> %3$s</a>',
				sprintf( '<span class="screen-reader-text">%s </span>', _x( 'Edit', 'Used before edit post link.', 'broad' ) ),
				get_edit_post_link(get_the_ID()),
				'Edit',
				$edit_class
			);
		}
		return;
	}
	
	if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
		broad_entry_date();
	}

	if ( 'post' == get_post_type() ) {
		$post_layout = broad_get_option_data( 'post_layout' );
		$class = ($post_layout->option_activate == 'masonry' && !is_single()) ? 'col-lg-4' : 'col-lg-2';
		
		printf( '<span class="screen-reader-text">%1$s </span><a class="%4$s" href="%2$s">%3$s</a>',
			_x( 'Author', 'Used before post author name.', 'broad' ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			get_the_author(),
			$class
		);
        
		$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'broad' ) );
		if ( current_user_can( 'edit_posts' ) ) { $cat_class = 'col-lg-3'; } else { $cat_class = 'col-lg-4'; }
		if ($post_layout->option_activate == 'masonry' && !is_single()) { $cat_class = 'col-lg-12'; }
		if ( $categories_list && broad_categorized_blog() ) {
			printf( '<span class="screen-reader-text">%1$s </span><span class="%2$s"> %3$s</span>',
				_x( 'Categories', 'Used before category names.', 'broad' ),
				$cat_class,
				$categories_list
			);
		}
	}

	if ( ! post_password_required() && comments_open() ) {
		$class = ($post_layout->option_activate == 'masonry' && !is_single()) ? 'col-lg-8' : 'col-lg-2';
		if ( $post_layout->option_activate == 'masonry' && !is_single() && !current_user_can('edit_post') ) { $class = 'col-lg-12'; }
		comments_popup_link(
			 __( 'Leave a comment', 'broad' ),
			 __( '1 Comment', 'broad' ),
			 __( '% Comments', 'broad' ), $class,
			 __( 'Commenting is off', 'broad' ) 
		);
	}
	
	if ( current_user_can('edit_posts') ) {
		if ($post_layout->option_activate == 'masonry' && !is_single()) {
		 $class = 'col-lg-4';
		} else {
			if ( !comments_open() ) {
				$class = 'col-lg-12';
			} else {
				$class = 'col-lg-1';
			}
		}
		printf( '%1$s<a href="%2$s" class="%4$s">%3$s</a>',
			sprintf( '<span class="screen-reader-text">%s </span>', _x( 'Edit', 'Used before edit post link.', 'broad' ) ),
			get_edit_post_link(get_the_ID()),
			__( 'Edit', 'broad' ),
			$class
		);
	}
	?>
	</details>
	<?php
}
endif;


if ( ! function_exists( 'broad_entry_date' ) ) :
/**
 * Prints HTML with date information for current post.
 *
 * Create your own broad_entry_date() function to override in a child theme.
 *
 * @since Broad 1.0
 */
function broad_entry_date() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
    
	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		get_the_date()
	);

	$post_layout = broad_get_option_data('post_layout');
	$class = ($post_layout->option_activate == 'masonry' && !is_single()) ? 'col-lg-8' : 'col-lg-3';
	printf( '<span class="screen-reader-text">%1$s </span><a href="%2$s" rel="bookmark" class="%4$s"> %3$s</a></span>',
		_x( 'Posted on', 'Used before publish date.', 'broad' ),
		esc_url( get_permalink() ),
		$time_string,
		$class
	);
}
endif;

/**
 * Determine whether blog/site has more than one category.
 *
 * @since Broad 1.0
 *
 * @return bool True of there is more than one category, false otherwise.
 */
function broad_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'broad_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'broad_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so broad_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so broad_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in {@see broad_categorized_blog()}.
 *
 * @since Broad 1.0
 */
function broad_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'broad_categories' );
}
add_action( 'edit_category', 'broad_category_transient_flusher' );
add_action( 'save_post',     'broad_category_transient_flusher' );

if ( ! function_exists( 'broad_post_thumbnail' ) ) :
/**
 * Displays an optional post thumbnail.
 *
 * Wraps the post thumbnail in an anchor element on index views, or a div
 * element when on single views.
 *
 * Create your own broad_post_thumbnail() function to override in a child theme.
 *
 * @since Broad 1.0
 */
function broad_post_thumbnail() {
	if ( post_password_required() || is_attachment() ) {
		return;
	}
	?>
	
	<?php if (is_singular()) : ?>
	<?php if (has_post_thumbnail()) : ?>
    <figure class="col-xs-12 article-thumbnail" aria-hidden="true" style="margin: 0 0 5% 0;">
		<?php the_post_thumbnail( '', array( 'class' => 'img-thumbnail img-responsive', 'alt' => the_title_attribute( 'echo=0' ), 'style' => 'height: 400px; max-height: 400px;' ) ); ?>
	</figure><!-- .article-thumbnail -->
	<?php else : return; ?>
	<?php endif; ?>
	
	<?php else : ?>
	<?php $post_layout = broad_get_option_data('post_layout'); if ($post_layout->option_activate == 'masonry') : ?>
		<figure class="col-xs-12 article-thumbnail" aria-hidden="true" style="margin: 0 0 6% 0; padding: 0%;">				
    		<?php if (has_post_thumbnail()) : ?>				
			<?php the_post_thumbnail( '', array( 'class' => 'img-responsive', 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
			<?php else : ?>
			<img src="<?php echo get_template_directory_uri() . '/images/no-featured.jpg' ?>" alt="no-thumbnail" class="img-responsive">
			<?php endif; ?>
		</figure><!-- .article-thumbnail -->
	<?php else : ?>			
	    <figure class="col-xs-2 article-thumbnail" aria-hidden="true">				
    		<?php if (has_post_thumbnail()) : ?>				
			<?php the_post_thumbnail( '', array( 'class' => 'img-thumbnail img-responsive', 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
			<?php else : ?>
			<img src="<?php echo get_template_directory_uri() . '/images/no-featured.jpg' ?>" alt="no-thumbnail" class="img-thumbnail img-responsive">
			<?php endif; ?>
		</figure><!-- .article-thumbnail -->
		<?php endif; ?>
	<?php endif; ?>
 
	<?php
}
endif;

if ( ! function_exists( 'broad_post_content' ) ) :
	/**
	 * Displays the post content.                                            
	 * 
	 * @since Broad 1.0
	 *                                                                                               
	 */
	function broad_post_content() {      
        ?>
    <?php if (is_single() || is_page()) : ?>
	    <header class="col-lg-12 article-content">                                                                	        
	        <div class="post-<?php the_ID(); ?>-content">
	        <?php the_content(); ?>
			</div><!-- .post-<?php the_ID(); ?>-content -->        
	    </header>
	<?php else : ?>
		<?php $post_layout = broad_get_option_data('post_layout'); if ($post_layout->option_activate == 'masonry') : ?>        
		    <header class="col-lg-12 article-content" style="margin:  4% 0 10% 0">
		        <?php the_title( sprintf( '<a href="%s" rel="bookmark"><h2>', esc_url( get_permalink() ) ), '</h2></a>' ); ?>
		        
		        <div class="post-<?php the_ID(); ?>-content">	
				<?php broad_post_excerpt(); ?>
				</div><!-- .post-<?php the_ID(); ?>-content -->        
		    </header>
	    <?php else : ?>	    
		    <header class="col-lg-8 article-content">
		        <?php the_title( sprintf( '<a href="%s" rel="bookmark"><h2>', esc_url( get_permalink() ) ), '</h2></a>' ); ?>
		        
		        <div class="post-<?php the_ID(); ?>-content">	
				<?php broad_post_excerpt(); ?>
				</div><!-- .post-<?php the_ID(); ?>-content -->        
		    </header>
	    <?php endif; ?>	
	<?php endif; ?>

		<?php
	}
endif;

/* Excerpt ********************************************/

    function broad_post_excerptlength_index() {
    	return 50;
    }
    function broad_post_excerptmore() {
    	return ' [...]';
    }
    
    function broad_post_excerptlength_masonry() {
    	return 20;
    }
    
    
    function broad_post_excerpt() {
    	$post_layout = broad_get_option_data('post_layout'); if ($post_layout->option_activate == 'masonry') {
			add_filter('excerpt_length', 'broad_post_excerptlength_masonry');
		} else { add_filter('excerpt_length', 'broad_post_excerptlength_index'); }			 
		add_filter('excerpt_more', 'broad_post_excerptmore');
	   
		$content = get_the_excerpt();
		$content = apply_filters('wptexturize', $content);
		$content = apply_filters('convert_chars', $content);
		
		echo $content;
    }
?>